@@ -7,9 +7,8 @@
 #' spline. These can be plotted with \code{\link{simGG}}.
 #' @param bspline a character string of the full \code{\link{pspline}} call
 #' used in \code{obj}. It should be exactly the same as how you entered it in
-#' \code{\link{coxph}}. You also need to enter a white spece before and after
-#' all equal (\code{=}) signs.
-#' @param bdata a numeric vector of splined variable's values.
+#' \code{\link{coxph}}.
+#' @param bdata a numeric vector of the splined variable's values.
 #' @param qi quantity of interest to simulate. Values can be
 #' \code{"Relative Hazard"}, \code{"First Difference"}, \code{"Hazard Ratio"},
 #' and \code{"Hazard Rate"}. The default is \code{qi = "Relative Hazard"}.
@@ -68,7 +67,6 @@
 #' multiple stratified models.
 #'
 #' @examples
-#' \dontrun{
 #' # Load Carpenter (2002) data
 #' data("CarpenterFdaData")
 #'
@@ -84,6 +82,7 @@
 #'            pspline(condavg3, df = 4) + pspline(orderent, df = 4) +
 #'            pspline(stafcder, df = 4), data = CarpenterFdaData)
 #'
+#' \dontrun{
 #' # Simulate Relative Hazards for orderent
 #' Sim1 <- coxsimSpline(M1, bspline = "pspline(stafcder, df = 4)",
 #'                     bdata = CarpenterFdaData$stafcder,
@@ -91,12 +90,12 @@
 #'                     Xj = seq(1100, 1700, by = 10),
 #'                     Xl = seq(1099, 1699, by = 10), spin = TRUE)
 #'
+#' }
 #' # Simulate Hazard Rates for orderent
 #' Sim2 <- coxsimSpline(M1, bspline = "pspline(orderent, df = 4)",
 #'                        bdata = CarpenterFdaData$orderent,
 #'                        qi = "Hazard Rate",
 #'                        Xj = seq(2, 53, by = 3), nsim = 100)
-#' }
 #'
 #' @seealso \code{\link{simGG}}, \code{\link{survival}}, \code{\link{strata}},
 #' and \code{\link{coxph}}
@@ -262,8 +261,8 @@ coxsimSpline <- function(obj, bspline, bdata, qi = "Relative Hazard", Xj = 1,
         Simb$QI <- exp(Simb$Xj * Simb$Coef)
     }
     else if (qi == "First Difference"){
-          if (length(Xj) != length(Xl)){
-          stop("Xj and Xl must be the same length.", call. = FALSE)
+            if (length(Xj) != length(Xl)){
+            stop("Xj and Xl must be the same length.", call. = FALSE)
         }
         else {
             Simbj <- MergeX(Xj) %>% rename(Xj = X)
@@ -273,7 +272,7 @@ coxsimSpline <- function(obj, bspline, bdata, qi = "Relative Hazard", Xj = 1,
             Simbj <- merge(Simbj, Xs, by = "Xj")
             Simbj$Comparison <- paste(Simbj$Xj, "vs.", Simbj$Xl)
 
-             Simbj$QI <- (exp((Simbj$Xj * Simbj$Coef) -
+            Simbj$QI <- (exp((Simbj$Xj * Simbj$Coef) -
                          (Simbl$Xl * Simbl$Coef)) - 1) * 100
             Simb <- Simbj
         }
@@ -336,17 +335,24 @@ coxsimSpline <- function(obj, bspline, bdata, qi = "Relative Hazard", Xj = 1,
                 call. = FALSE)
         }
     } else if (qi == "Hazard Ratio"){
-          SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$Xj, SimbPerc$QI,
-                                SimbPerc$Comparison)
-          names(SimbPercSub) <- c("SimID", "Xj", "QI", "Comparison")
+        SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$Xj, SimbPerc$QI,
+                            SimbPerc$Comparison)
+        names(SimbPercSub) <- c("SimID", "Xj", "QI", "Comparison")
     } else if (qi == "Relative Hazard"){
-          SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$Xj, SimbPerc$QI)
-          names(SimbPercSub) <- c("SimID", "Xj", "QI")
+        SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$Xj, SimbPerc$QI)
+        names(SimbPercSub) <- c("SimID", "Xj", "QI")
     } else if (qi == "First Difference"){
         SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$Xj, SimbPerc$QI,
             SimbPerc$Comparison)
         names(SimbPercSub) <- c("SimID", "Xj", "QI", "Comparison")
     }
-    class(SimbPercSub) <- c("simspline", qi, "data.frame")
-    SimbPercSub
+    # Add in distribution of b
+    b <- gsub('^pspline\\(', '', bspline)
+    b <- gsub(',.*)$', '', b)
+    rug <- bdata
+    out <- list(sims = SimbPercSub, rug = rug)
+
+    class(out) <- c("simspline", qi, "coxsim")
+    attr(out, 'xaxis') <- b
+    out
 }
